@@ -1,5 +1,5 @@
 /* findutils-version.c -- show version information for findutils
-   Copyright (C) 2007, 2010 Free Software Foundation, Inc.
+   Copyright (C) 2007, 2010, 2011 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,12 +15,17 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+/* config.h must be included first. */
 #include <config.h>
-#include "stdio-safer.h"
+
+/* system headers would go here if we needed any. */
+
+/* gnulib headers. */
+#include "gettext.h"
 #include "version-etc.h"
-#include "gnulib-version.h"
-
 
+/* find headers. */
+#include "findutils-version.h"
 
 #if ENABLE_NLS
 # include <libintl.h>
@@ -28,24 +33,14 @@
 #else
 # define _(Text) Text
 #endif
-#ifdef gettext_noop
-# define N_(String) gettext_noop (String)
-#else
-/* See locate.c for explanation as to why not use (String) */
-# define N_(String) String
-#endif
-
-
 
 #ifdef _LIBC
 /* In the GNU C library, there is a predefined variable for this.  */
 # define program_name program_invocation_name
 #endif
 
-
 extern char *program_name;
-char *version_string = VERSION;
-
+const char *version_string = VERSION;
 
 void
 display_findutils_version (const char *official_name)
@@ -61,5 +56,4 @@ display_findutils_version (const char *official_name)
 	       _("James Youngman"),
 	       _("Kevin Dalley"),
 	       (const char*) NULL);
-  printf (_("Built using GNU gnulib version %s\n"), gnulib_version);
 }
